import {Injectable} from '@angular/core';
import {Observable} from 'rxjs';
import {map} from 'rxjs/operators';
import {Activity} from '@nspop/gm-web-facade-api';
import {CarePlanService} from '../api/care-plan.service';
import {DataCardService} from '../api/data-card.service';

export interface FakeDataCard {
    CareLevel: string;
    gestationAge: string;
    term: string;
    multiple: string;
    Parity: string;
    conditions: string[];
    translationAssistance: string;
    smokingStatus: string;
}

@Injectable({providedIn: 'root'})
export class ActivitiesService {
  constructor(
    private carePlanService: CarePlanService,
    private dataCardService: DataCardService,
  ) { }
  public dummyDataCard$: Observable<FakeDataCard> = this.dataCardService.activeDataCard$.pipe(
    map(dataCard => {
      return {
        CareLevel: '4',
        gestationAge: '22+1 uger',
        term: '05-11-2020',
        multiple: 'Ja',
        Parity: '0',
        conditions: ['Diabetes', 'Hovedpine', 'KOL'],
        translationAssistance: 'Ja',
        smokingStatus: 'Ja'
      };
    }));
  private activities$: Observable<Activity[]> = this.carePlanService.carePlan$.pipe(
    map(carePlan => carePlan?.activities ?? []),
  );

  public futureActivities$: Observable<Activity[]> = this.activities$.pipe(
    map(activities => activities.filter(activity => !activity.plannedTime?.from || activity.plannedTime.from >= new Date()))
  );

  public pastActivities$: Observable<Activity[]> = this.activities$.pipe(
    map(activities => activities.filter(activity => activity.plannedTime?.from && activity.plannedTime.from < new Date()))
  );
}
