import { ComponentFixture, TestBed } from '@angular/core/testing';

import { EditPlanModalComponent } from './edit-plan-modal.component';
import {WeekNumberPipe} from '../../pipes/week-number.pipe';
import {MatButtonModule} from '@angular/material/button';
import {ModalComponent} from '../../modals/modal/modal.component';
import {Component, Input} from '@angular/core';
import {MatIcon, MatIconModule} from '@angular/material/icon';
import {FormsModule, ReactiveFormsModule} from '@angular/forms';
import {MatCheckboxModule} from '@angular/material/checkbox';
import {DirtyGuard} from '../../confirm-navigation-if-dirty.framework';

@Component({
  // tslint:disable-next-line:component-selector
  selector: 'mat-icon',
  template: '<span></span>'
})
class MockMatIconComponent {
  @Input() svgIcon: any;
  @Input() fontSet: any;
  @Input() fontIcon: any;
}

describe('EditPlanModalComponent', () => {
  let component: EditPlanModalComponent;
  let fixture: ComponentFixture<EditPlanModalComponent>;

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [ EditPlanModalComponent, WeekNumberPipe, ModalComponent, WeekNumberPipe],
      imports: [MatIconModule, MatButtonModule, ReactiveFormsModule, FormsModule, MatCheckboxModule],
      providers: [
        {provide: DirtyGuard, useValue: {canDeactivate: () => true}}
      ]
    })
    .overrideModule(MatIconModule, {
      remove: {
        declarations: [MatIcon],
        exports: [MatIcon]
      },
      add: {
        declarations: [MockMatIconComponent],
        exports: [MockMatIconComponent]
      }
    })
    .compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(EditPlanModalComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  it('should return true if some but not all activities are selected', () => {
    expect(component.someButNotAllSelected()).toBeFalse();
    component.selectedActivities[1] = true;
    component.selectedActivities[3] = true;
    component.selectedActivities[5] = true;
    expect(component.someButNotAllSelected()).toBeTrue();
  });

  it('should return false if all activities are selected', () => {
    component.selectedActivities[1] = true;
    expect(component.someButNotAllSelected()).toBeTrue();
    component.selectedActivities = component.selectedActivities.map(() => true);
    expect(component.someButNotAllSelected()).toBeFalse();
  });
});
