import {Component, Input, OnInit, ViewChild} from '@angular/core';
import {Activity, CarePlan} from '@nspop/gm-web-facade-api';
import getWeek from 'date-fns/getWeek';
import {ModalComponent} from '../../modals/modal/modal.component';
import OwnershipEnum = Activity.OwnershipEnum;

@Component({
  selector: 'app-edit-plan-modal',
  templateUrl: './edit-plan-modal.component.html',
  styleUrls: ['./edit-plan-modal.component.scss']
})
export class EditPlanModalComponent implements OnInit {
  @ViewChild('modal') public modalComponent: ModalComponent | undefined;
  @Input() public selectedActivities: boolean[] = [];
  public allChecked = false;
  public carePlan: CarePlan;
  public additionalActivities: Activity[] = [];
  constructor() {
    const dummyActivities: Activity[] = [];
    const now = new Date();
    for (let i = 0; i < 15; i++) {
      dummyActivities.push({
        plannedTime: { from: now, to: now},
        ownership: 'currentUser' as OwnershipEnum,
        sortDate: now,
        gestationWeek: '' + i,
        notes: [],
        observations: [],
        practitioner: {} as any,
        status: 'expected',
        title: 'Første konsultation ved læge'
      });
      this.selectedActivities.push(false);
    }
    for (let i = 0; i < 3; i++) {
      this.additionalActivities.push({
        plannedTime: { from: now, to: now},
        ownership: 'otherUser' as OwnershipEnum,
        sortDate: now,
        gestationWeek: '' + i,
        notes: [],
        observations: [],
        practitioner: {} as any,
        status: 'expected',
        title: 'Jordemoderbesøg',
      });
    }
    this.carePlan = {
      activities: dummyActivities,
      patient: 'John Doe',
      title: 'Basis forløbsplan',
      responsibleOrganization: {} as any,
    };
  }

  ngOnInit(): void {
  }

  public setVisible(isVisible: boolean): void {
    this.modalComponent?.setVisible(isVisible);
  }

  public getWeekNumber(from: Date): number {
    return getWeek(from);
  }
  public submit(): void { }

  // These functions are subject to change as the exact model for templates -->
  // and its mapping to actual careplans has yet to be determined.
  toggleAll(): void {
    this.selectedActivities = this.selectedActivities.map(() => !this.allChecked);
    this.allChecked = !this.allChecked;
  }

  public someButNotAllSelected(): boolean {
    const sumSelected = this.selectedActivities.filter(a => a).length;
    return sumSelected > 0 && sumSelected < this.selectedActivities.length;
  }
}
