import {Component, forwardRef, Input, OnChanges, SimpleChanges} from '@angular/core';
import {CreateUltrasoundObservationsRequest} from '@nspop/gm-web-facade-api';
import {ControlContainer, ControlValueAccessor, NG_VALUE_ACCESSOR, NgForm} from '@angular/forms';
import {DataCardWrapper} from '../../../model-wrappers/dataCard.wrapper';
import deepEqual from 'deep-equal';
import {copy} from '../../../../utils/copy';

export const APP_EDIT_ULTRASOUND_CONTROL_VALUE_ACCESSOR: any = {
  provide: NG_VALUE_ACCESSOR,
  useExisting: forwardRef(() => EditUltrasoundComponent),
  multi: true
};

type ScanningType = 'trimester1' | 'trimester2' | 'other';

@Component({
  selector: 'app-edit-ultrasound',
  templateUrl: './edit-ultrasound.component.html',
  styleUrls: ['./edit-ultrasound.component.scss'],
  providers: [APP_EDIT_ULTRASOUND_CONTROL_VALUE_ACCESSOR],
  viewProviders: [ { provide: ControlContainer, useExisting: NgForm } ]
})
export class EditUltrasoundComponent implements OnChanges, ControlValueAccessor {
  @Input()  dataCard: DataCardWrapper|undefined;
  public trimesterScan?: ScanningType;
  public observationData: CreateUltrasoundObservationsRequest|undefined;
  private dirtyAble = false;

  public onChangeCallback: (newValue: CreateUltrasoundObservationsRequest|undefined) => any = () => {};
  private onTouchedCallback: () => any = () => {};

  constructor() { }

  get value(): CreateUltrasoundObservationsRequest|undefined {
    return this.observationData;
  }

  set value(value: CreateUltrasoundObservationsRequest|undefined) {
    if (!deepEqual(value, this.observationData)) {
      this.observationData = value;
      if (this.dirtyAble) {

        this.onChangeCallback(value);
      }
      if (!this.dirtyAble && this.observationData) { // We don't want to mark the field as dirty while data gets initialized
        this.dirtyAble = true;
      }
    }
  }

  ngOnChanges(changes: SimpleChanges): void {
    if (changes.dataCard) {
      this.handleFetusCountUpdate(this.dataCard?.fetusCount || 0);
    }
  }

  registerOnChange(fn: any): void {
    this.onChangeCallback = fn;
  }

  registerOnTouched(fn: any): void {
    this.onTouchedCallback = fn;
  }

  writeValue(newValue: CreateUltrasoundObservationsRequest): void {
    this.value = newValue;
  }

  public handleFetusCountUpdate(fetusCount: number): void {
    if (this.observationData && this.observationData.fetuses) {
      if (!fetusCount || fetusCount === this.observationData.fetuses.length) {
        return; // If the user is claiming to have 0 feti something is wrong... We'll hold off on deleting stuff
      }
      if (fetusCount < this.observationData.fetuses.length) {
        this.observationData.fetuses = this.observationData.fetuses.slice(0, fetusCount);
      }
      if (fetusCount > this.observationData.fetuses.length) {
        for (let neededFeti = fetusCount - this.observationData.fetuses.length; neededFeti > 0; neededFeti--) {
          this.observationData.fetuses.push(
            {id: `Foster ${this.observationData.fetuses.length + 1}`}
          );
        }
      }
      this.observationData = copy(this.observationData); // Trigger onChange if model has changed
    }
  }

  public handleTrimesterScanUpdate(value: ScanningType): void {
    switch (value) {
      case 'trimester1':
        if (this.dataCard) {
          this.dataCard.firstTrimesterScan = new Date();
        }
        break;
      case 'trimester2':
        if (this.dataCard) {
          this.dataCard.secondTrimesterScan = new Date();
        }
        break;
      case 'other':
      default:
        break;
    }
    this.onChangeCallback(this.value); // Mark form as dirty for updates to this field
  }
}
